# function to estimate fitness from a single snapshot  2016-5-31 Thong Pham


mcPAFit <- function(file_name, burn_in = 1000, needed_sample = 1000, skip = 1, B = 1,
                    step_s = 0.1, lambda = 1, G = 10000, s = 1, h_s_shape = 5, h_s_rate = 5,
                    not_start_A = 1, file_A = "", not_start_f = 1,file_f = "", filename = "network",
                    only_active_node = 1, random = 0) {
  if (1 == random) {
      data <-  read.table(file_name)
      N <- dim(data)[1]
      data <- data[sample(1:N,N,replace = FALSE),]
      write.table(data, file = paste(file_name,"randomized"), row.names = FALSE, col.names = FALSE);
      file_name <- paste(file_name,"randomized")
  }
  m <- c(file_name, burn_in , needed_sample , skip , B ,
         step_s , lambda , G, s , h_s_shape , h_s_rate ,
         not_start_A, file_A, not_start_f, file_f, filename, only_active_node)
  .mcmc_running(m)      
}
